@@ -1,11 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "consult-dir" "0.1"
+(define-package "consult-dir" "20251020.416"
   "Insert paths into the minibuffer prompt."
   '((emacs   "26.1")
-    (consult "0.9")
-    (project "0.6.0"))
+    (project "0.3.0")
+    (consult "2.0"))
   :url "https://github.com/karthink/consult-dir"
-  :commit "08f543ae6acbfc1ffe579ba1d00a5414012d5c0b"
-  :revdesc "08f543ae6acb"
+  :commit "1497b46d6f48da2d884296a1297e5ace1e050eb5"
+  :revdesc "1497b46d6f48"
   :keywords '("convenience")
+  :authors '(("Karthik Chikmagalur" . "karthik.chikmagalur@gmail.com"))
   :maintainers '(("Karthik Chikmagalur" . "karthik.chikmagalur@gmail.com")))
